Package: aphylo
Title: Statistical Inference and Prediction of Annotations in
        Phylogenetic Trees
Authors@R: c(person("George", "Vega Yon", role=c("aut","cre"),
         email="g.vegayon@gmail.com", comment = c(ORCID = "0000-0002-3171-0844")),
         person("National
         Cancer Institute (NCI)", role = "fnd", comment = "Grant Number
         5P01CA196569-02"),
         person("USC Biostatistics", role = "cph")
         )
Version: 0.3-6
Description: Implements a parsimonious evolutionary model to analyze and
  predict gene-functional annotations in phylogenetic trees as described in Vega
  Yon et al. (2021) <doi:10.1371/journal.pcbi.1007948>. Focusing on
  computational efficiency, 'aphylo' makes it possible to estimate pooled
  phylogenetic models, including thousands (hundreds) of annotations (trees) in
  the same run. The package also provides the tools for visualization of
  annotated phylogenies, calculation of posterior probabilities (prediction)
  and goodness-of-fit assessment featured in Vega Yon et al. (2021).
Depends: R (>= 3.5.0), ape (>= 5.0)
LazyData: true
Imports: Rcpp (>= 0.12.1), Matrix, methods, coda, fmcmc, utils, MASS,
        xml2
Suggests: covr, knitr, tinytest, AUC, rmarkdown,
VignetteBuilder: knitr
LinkingTo: Rcpp
RoxygenNote: 7.3.3
Encoding: UTF-8
URL: https://github.com/USCbiostats/aphylo
BugReports: https://github.com/USCbiostats/aphylo/issues
Classification/MSC: 90C35, 90B18, 91D30
License: MIT + file LICENSE
NeedsCompilation: yes
Packaged: 2026-01-09 13:42:10 UTC; runner
Author: George Vega Yon [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-3171-0844>),
  National Cancer Institute (NCI) [fnd] (Grant Number 5P01CA196569-02),
  USC Biostatistics [cph]
Maintainer: George Vega Yon <g.vegayon@gmail.com>
Repository: CRAN
Date/Publication: 2026-01-09 16:10:02 UTC
Built: R 4.6.0; aarch64-apple-darwin23; 2026-04-26 02:37:58 UTC; unix
Archs: aphylo.so.dSYM
