# Generated by roxygen2: do not edit by hand

S3method("[",aphylo)
S3method("[",multiAphylo)
S3method("[<-",aphylo)
S3method(LogLike,aphylo)
S3method(LogLike,aphylo_pruner)
S3method(LogLike,multiAphylo)
S3method(LogLike,multiAphylo_pruner)
S3method(Nann,aphylo)
S3method(Nann,aphylo_estimates)
S3method(Nann,aphylo_pruner)
S3method(Nann,multiAphylo)
S3method(Nann,multiAphylo_pruner)
S3method(Nannotated,aphylo)
S3method(Nannotated,aphylo_estimates)
S3method(Nannotated,aphylo_pruner)
S3method(Nannotated,multiAphylo)
S3method(Nannotated,multiAphylo_pruner)
S3method(Nedge,aphylo)
S3method(Nedge,aphylo_estimates)
S3method(Nedge,multiAphylo)
S3method(Nedge,multiAphylo_pruner)
S3method(Nnode,aphylo)
S3method(Nnode,aphylo_estimates)
S3method(Nnode,aphylo_pruner)
S3method(Nnode,multiAphylo)
S3method(Nnode,multiAphylo_pruner)
S3method(Ntip,aphylo)
S3method(Ntip,aphylo_estimates)
S3method(Ntip,aphylo_pruner)
S3method(Ntip,multiAphylo)
S3method(Ntip,multiAphylo_pruner)
S3method(Ntrees,aphylo)
S3method(Ntrees,aphylo_estimates)
S3method(Ntrees,aphylo_pruner)
S3method(Ntrees,multiAphylo)
S3method(Ntrees,multiAphylo_pruner)
S3method(Ntrees,multiPhylo)
S3method(Ntrees,phylo)
S3method(accuracy_sifter,aphylo_estimates)
S3method(accuracy_sifter,default)
S3method(aphylo_cv,formula)
S3method(as.phylo,aphylo)
S3method(as.phylo,matrix)
S3method(balance_ann,aphylo)
S3method(balance_ann,default)
S3method(balance_ann,multiAphylo)
S3method(c,aphylo)
S3method(c,multiAphylo)
S3method(coef,aphylo_estimates)
S3method(list_offspring,aphylo)
S3method(list_offspring,phylo)
S3method(list_parents,aphylo)
S3method(list_parents,phylo)
S3method(logLik,aphylo_estimates)
S3method(new_aphylo,phylo)
S3method(new_aphylo_pruner,aphylo)
S3method(new_aphylo_pruner,multiAphylo)
S3method(plot,aphylo)
S3method(plot,aphylo_auc)
S3method(plot,aphylo_estimates)
S3method(plot,aphylo_prediction_score)
S3method(plot_logLik,aphylo)
S3method(plot_logLik,aphylo_estimates)
S3method(plot_logLik,formula)
S3method(predict,aphylo_estimates)
S3method(predict_pre_order,aphylo)
S3method(predict_pre_order,aphylo_estimates)
S3method(prediction_score,aphylo_estimates)
S3method(prediction_score,default)
S3method(prediction_score,list)
S3method(prediction_score,matrix)
S3method(print,aphylo)
S3method(print,aphylo_auc)
S3method(print,aphylo_estimates)
S3method(print,aphylo_prediction_score)
S3method(print,multiAphylo)
S3method(summary,aphylo)
S3method(vcov,aphylo_estimates)
S3method(window,aphylo_estimates)
export(APHYLO_DEFAULT_MCMC_CONTROL)
export(APHYLO_PARAM_DEFAULT)
export(LogLike)
export(Nann)
export(Nannotated)
export(Ntrees)
export(accuracy_sifter)
export(aphylo_cv)
export(aphylo_formula)
export(aphylo_from_data_frame)
export(aphylo_mcmc)
export(aphylo_mle)
export(auc)
export(balance_ann)
export(bprior)
export(dist2root)
export(get_postorder)
export(imputate_duplications)
export(list_offspring)
export(list_parents)
export(mislabel)
export(new_aphylo)
export(new_aphylo_pruner)
export(plot_logLik)
export(plot_multivariate)
export(predict_brute_force)
export(predict_pre_order)
export(prediction_score)
export(raphylo)
export(rdrop_annotations)
export(read.panther)
export(read_nhx)
export(read_panther)
export(read_pli)
export(rmultiAphylo)
export(sim_fun_on_tree)
export(sim_tree)
export(states)
export(uprior)
export(write_pli)
import(methods)
importClassesFrom(Matrix,dgCMatrix)
importFrom(MASS,ginv)
importFrom(Matrix,Matrix)
importFrom(Matrix,colSums)
importFrom(Matrix,rowSums)
importFrom(Rcpp,evalCpp)
importFrom(ape,Nedge)
importFrom(ape,Nnode)
importFrom(ape,Ntip)
importFrom(ape,as.phylo)
importFrom(ape,plot.phylo)
importFrom(coda,mcmc)
importFrom(coda,mcmc.list)
importFrom(fmcmc,MCMC)
importFrom(grDevices,adjustcolor)
importFrom(grDevices,colors)
importFrom(grDevices,rgb)
importFrom(grDevices,trans3d)
importFrom(graphics,abline)
importFrom(graphics,contour)
importFrom(graphics,image)
importFrom(graphics,legend)
importFrom(graphics,mtext)
importFrom(graphics,par)
importFrom(graphics,persp)
importFrom(graphics,plot)
importFrom(graphics,plot.new)
importFrom(graphics,plot.window)
importFrom(graphics,points)
importFrom(graphics,polygon)
importFrom(graphics,rect)
importFrom(graphics,segments)
importFrom(graphics,yinch)
importFrom(stats,as.formula)
importFrom(stats,coef)
importFrom(stats,complete.cases)
importFrom(stats,dbeta)
importFrom(stats,optim)
importFrom(stats,optimHess)
importFrom(stats,predict)
importFrom(stats,runif)
importFrom(stats,update.formula)
importFrom(stats,var)
importFrom(stats,vcov)
importFrom(stats,window)
importFrom(utils,combn)
importFrom(utils,getFromNamespace)
importFrom(utils,head)
importFrom(utils,tail)
importFrom(xml2,as_list)
importFrom(xml2,read_html)
importMethodsFrom(Matrix,t)
useDynLib(aphylo, .registration=TRUE)
